@@ -53,7 +53,8 @@ int game_run()
 	u16* temp;
 	int score;
 	int die = 0;
-	
+	char foo[100];
+
 	int wave = 0;
 	int wave_timer = 0;
 	int wave_length = 300;
@@ -164,10 +165,15 @@ int game_run()
 		if(starbg.x_scroll > (256 * 240)) starbg.x_scroll = 0;
 		UpdateBackground(&starbg);
 		CopyOAM();
+		
+		sprintf(foo, "%d\n", REG_TM0D);
+		//print(foo);
+		process_soundbuffer();
 		gba_vsync();
 	}
 
 	/* we're dead - do the "game over" thang */
+	play_sound(&exp_sample);
 	for(loop=0; loop < PLAYER_EXPLODE_SPEED * EXPLOSION_FRAMES_NUM; loop++)
 	{
 		aliens_draw(&g);
