@@ -1,4 +1,4 @@
-extern const unsigned short sprites_Palette[256] = {
+const unsigned short sprites_Palette[256] = {
 0x1406, 0x0000, 0x6739, 0x7fff, 0x7905, 0x739c, 0x5294, 0x7eb0, 
 0x7dcb, 0x77bd, 0x1be6, 0x43f0, 0x0d9f, 0x2bff, 0x029e, 0x00cf, 
 0x7a3f, 0x701f, 0x5016, 0x36db, 0x2e7a, 0x0cf5, 0x044f, 0x086d, 
